Index: lib/filterClasses.js |
diff --git a/lib/filterClasses.js b/lib/filterClasses.js |
index 1932a6895b6b4d15897d2a104d416be74e2bd80a..bd86d9346f50b733df532f09235e85fb0d57f346 100644 |
--- a/lib/filterClasses.js |
+++ b/lib/filterClasses.js |
@@ -754,11 +754,17 @@ RegExpFilter.typeMap = { |
BACKGROUND: 4, // Backwards compat, same as IMAGE |
POPUP: 0x10000000, |
- ELEMHIDE: 0x40000000 |
+ GENERICBLOCK: 0x20000000, |
+ ELEMHIDE: 0x40000000, |
+ GENERICHIDE: 0x80000000 |
}; |
-// DOCUMENT, ELEMHIDE, POPUP options shouldn't be there by default |
-RegExpFilter.prototype.contentType &= ~(RegExpFilter.typeMap.DOCUMENT | RegExpFilter.typeMap.ELEMHIDE | RegExpFilter.typeMap.POPUP); |
+// DOCUMENT, ELEMHIDE, POPUP, GENERICHIDE and GENERICBLOCK options shouldn't be there by default |
Thomas Greiner
2015/08/20 11:36:07
Detail: Mind the 80 character line limitation (als
kzar
2015/08/25 17:42:08
Done.
|
+RegExpFilter.prototype.contentType &= ~(RegExpFilter.typeMap.DOCUMENT | |
+ RegExpFilter.typeMap.ELEMHIDE | |
+ RegExpFilter.typeMap.POPUP | |
+ RegExpFilter.typeMap.GENERICHIDE | |
+ RegExpFilter.typeMap.GENERICBLOCK); |
/** |
* Class for blocking filters |